@@ -31,8 +31,8 @@ class ConfigOperationPrivate : public QObject
     Q_OBJECT
 
 public:
-    ConfigOperationPrivate(ConfigOperation *qq);
-    virtual ~ConfigOperationPrivate();
+    explicit ConfigOperationPrivate(ConfigOperation *qq);
+    ~ConfigOperationPrivate() override;
 
     // For out-of-process
     void requestBackend();
