@@ -40,6 +40,7 @@ class Q_DECL_HIDDEN Output::Private
         replicationSource(0),
         rotation(None),
         scale(1.0),
+        logicalSize(QSizeF()),
         connected(false),
         enabled(false),
         primary(false),
@@ -92,6 +93,7 @@ class Q_DECL_HIDDEN Output::Private
     QSize size;
     Rotation rotation;
     qreal scale;
+    QSizeF logicalSize;
     bool connected;
     bool enabled;
     bool primary;
@@ -214,6 +216,7 @@ void Output::setName(const QString& name)
     Q_EMIT outputChanged();
 }
 
+// TODO KF6: remove this deprecated method
 QString Output::hash() const
 {
     if (edid() && edid()->isValid()) {
@@ -393,6 +396,7 @@ void Output::setSize(const QSize& size)
     Q_EMIT sizeChanged();
 }
 
+// TODO KF6: make the Rotation enum an enum class and align values with Wayland transformation property
 Output::Rotation Output::rotation() const
 {
     return d->rotation;
@@ -423,6 +427,43 @@ void Output::setScale(qreal factor)
     emit scaleChanged();
 }
 
+QSizeF Output::logicalSize() const
+{
+    if (d->logicalSize.isValid()) {
+        return d->logicalSize;
+    }
+
+    QSizeF size = enforcedModeSize();
+    if (!size.isValid()) {
+        return QSizeF();
+    }
+    size = size / d->scale;
+
+    // We can't use d->size, because d->size does not reflect the actual rotation() set by caller.
+    // It is only updated when we get update from KScreen, but not when user changes mode or
+    // rotation manually.
+
+    if (!isHorizontal()) {
+        size = size.transposed();
+    }
+    return size;
+}
+
+QSizeF Output::explicitLogicalSize() const
+{
+    return d->logicalSize;
+}
+
+void Output::setLogicalSize(const QSizeF &size)
+{
+    if (qFuzzyCompare(d->logicalSize.width(), size.width())
+                      && qFuzzyCompare(d->logicalSize.height(), size.height())) {
+        return;
+    }
+    d->logicalSize = size;
+    Q_EMIT logicalSizeChanged();
+}
+
 bool Output::isConnected() const
 {
     return d->connected;
@@ -556,19 +597,10 @@ QSize Output::enforcedModeSize() const
 
 QRect Output::geometry() const
 {
-    QSize size = enforcedModeSize();
+    QSize size = logicalSize().toSize();
     if (!size.isValid()) {
         return QRect();
     }
-    size = size / d->scale;
-
-    // We can't use QRect(d->pos, d->size), because d->size does not reflect the
-    // actual rotation() set by caller, it's only updated when we get update from
-    // KScreen, but not when user changes mode or rotation manually
-
-    if (!isHorizontal()) {
-        size = size.transposed();
-    }
 
     return QRect(d->pos, size);
 }
